ZIP: A zero-inflated Poisson family

View source: R/auxilaryfunctions.R

ZIPR Documentation

A zero-inflated Poisson family

Description

This is basically a carbon-copy of gamlss.dist::ZIP(), which establishes the zero-inflated Poisson distribution as a family for use in the main rpql function. The distribution is parametrized in terms of the mean of the Poisson distribution, and the probability of zero inflation.

Full credit goes to the GAMLSS team for the originalgamlss.dist::ZIP() family class, which was copied into this package due to issues with the gamlss.dist package being archived at some point (but might have since been resolved?!)

Usage

 
ZIP()
  

Details

Used in the form rpql(y, ..., family = ZIP(), ...).

Value

An object of class "family"

Author(s)

Francis K.C. Hui [aut, cre]

Maintainer: Francis K.C. Hui <fhui28@gmail.com>


rpql documentation built on Sept. 7, 2026, 1:06 a.m.