View source: R/auxilaryfunctions.R
| ZIP | R Documentation |
This is basically a carbon-copy of gamlss.dist::ZIP(), which establishes the zero-inflated Poisson distribution as a family for use in the main rpql function. The distribution is parametrized in terms of the mean of the Poisson distribution, and the probability of zero inflation.
Full credit goes to the GAMLSS team for the originalgamlss.dist::ZIP() family class, which was copied into this package due to issues with the gamlss.dist package being archived at some point (but might have since been resolved?!)
ZIP()
Used in the form rpql(y, ..., family = ZIP(), ...).
An object of class "family"
Francis K.C. Hui [aut, cre]
Maintainer: Francis K.C. Hui <fhui28@gmail.com>
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.